{% extends "admin/base.html" %}
{% load i18n static %}

{% block title %}{% if form.email.errors %}{% translate "Error:" %} {% endif %}{{ block.super }}{% endblock %}
{% block extrastyle %}{{ block.super }}{% endblock %}
{% block breadcrumbs %}
{% endblock %}

{% block body %}

<div class="row mx-0 align-items-center justify-content-center h-100 position-absolute w-100">
  <div class="col-sm-6">
    <div class="card bg-white shadow-sm p-3 rounded">
      <h3>{% translate 'Forgotten your password?' %}</h3>
      <p class="">{% translate 'Enter your email address below, and we’ll email instructions for setting a new one.' %}</p>

      <form method="post">{% csrf_token %}
        <fieldset class="module aligned">
          <div class="form-row field-email">
            {{ form.email.errors }}
            <div class="form-group">
              <label for="id_email" class="form-label">{% translate 'Email address:' %}</label>
              <input name="{{ form.email.html_name }}" id="{{ form.email.id_for_label }}" class="form-control" type="email"  />
            </div>
          </div>
        </fieldset>
        <div class="submit-row mt-3">
          <input type="submit" class="btn btn-dark btn-block w-100 btn-lg" style="font-size: 17px" value="{% translate 'Reset my password' %}">
        </div>

        <hr  class="separator" />

        <p> <a href="{% url 'palette_admin:login' %}"> Back to Login </a> </p>
      </form>
    </div>
  </div>
</div>

{% endblock %}
